@@ -3,18 +3,18 @@
 
 # ***********************IMPORTANT NMAP LICENSE TERMS************************
 # *                                                                         *
-# * The Nmap Security Scanner is (C) 1996-2015 Insecure.Com LLC. Nmap is    *
-# * also a registered trademark of Insecure.Com LLC.  This program is free  *
-# * software; you may redistribute and/or modify it under the terms of the  *
-# * GNU General Public License as published by the Free Software            *
-# * Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE CLARIFICATIONS  *
-# * AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your right to use,    *
-# * modify, and redistribute this software under certain conditions.  If    *
-# * you wish to embed Nmap technology into proprietary software, we sell    *
-# * alternative licenses (contact sales@nmap.com).  Dozens of software      *
-# * vendors already license Nmap technology such as host discovery, port    *
-# * scanning, OS detection, version detection, and the Nmap Scripting       *
-# * Engine.                                                                 *
+# * The Nmap Security Scanner is (C) 1996-2016 Insecure.Com LLC ("The Nmap  *
+# * Project"). Nmap is also a registered trademark of the Nmap Project.     *
+# * This program is free software; you may redistribute and/or modify it    *
+# * under the terms of the GNU General Public License as published by the   *
+# * Free Software Foundation; Version 2 ("GPL"), BUT ONLY WITH ALL OF THE   *
+# * CLARIFICATIONS AND EXCEPTIONS DESCRIBED HEREIN.  This guarantees your   *
+# * right to use, modify, and redistribute this software under certain      *
+# * conditions.  If you wish to embed Nmap technology into proprietary      *
+# * software, we sell alternative licenses (contact sales@nmap.com).        *
+# * Dozens of software vendors already license Nmap technology such as      *
+# * host discovery, port scanning, OS detection, version detection, and     *
+# * the Nmap Scripting Engine.                                              *
 # *                                                                         *
 # * Note that the GPL places important restrictions on "derivative works",  *
 # * yet it does not provide a detailed definition of that term.  To avoid   *
@@ -56,12 +56,19 @@
 # * particularly including the GPL Section 3 requirements of providing      *
 # * source code and allowing free redistribution of the work as a whole.    *
 # *                                                                         *
-# * As another special exception to the GPL terms, Insecure.Com LLC grants  *
+# * As another special exception to the GPL terms, the Nmap Project grants  *
 # * permission to link the code of this program with any version of the     *
 # * OpenSSL library which is distributed under a license identical to that  *
 # * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
 # * linked combinations including the two.                                  *
 # *                                                                         *
+# * The Nmap Project has permission to redistribute Npcap, a packet         *
+# * capturing driver and library for the Microsoft Windows platform.        *
+# * Npcap is a separate work with it's own license rather than this Nmap    *
+# * license.  Since the Npcap license does not permit redistribution        *
+# * without special permission, our Nmap Windows binary packages which      *
+# * contain Npcap may not be redistributed without special permission.      *
+# *                                                                         *
 # * Any redistribution of Covered Software, including any derived works,    *
 # * must obey and carry forward all of the terms of this license, including *
 # * obeying all GPL rules and restrictions.  For example, source code of    *
@@ -101,12 +108,12 @@
 # * to the dev@nmap.org mailing list for possible incorporation into the    *
 # * main distribution.  By sending these changes to Fyodor or one of the    *
 # * Insecure.Org development mailing lists, or checking them into the Nmap  *
-# * source code repository, it is understood (unless you specify otherwise) *
-# * that you are offering the Nmap Project (Insecure.Com LLC) the           *
-# * unlimited, non-exclusive right to reuse, modify, and relicense the      *
-# * code.  Nmap will always be available Open Source, but this is important *
-# * because the inability to relicense code has caused devastating problems *
-# * for other Free Software projects (such as KDE and NASM).  We also       *
+# * source code repository, it is understood (unless you specify            *
+# * otherwise) that you are offering the Nmap Project the unlimited,        *
+# * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
+# * will always be available Open Source, but this is important because     *
+# * the inability to relicense code has caused devastating problems for     *
+# * other Free Software projects (such as KDE and NASM).  We also           *
 # * occasionally relicense the code to third parties as discussed above.    *
 # * If you wish to specify special license conditions of your               *
 # * contributions, just say so when you send them.                          *
@@ -123,6 +130,7 @@ import re
 
 from types import StringTypes
 from ConfigParser import DuplicateSectionError, NoSectionError, NoOptionError
+from ConfigParser import Error as ConfigParser_Error
 
 from zenmapCore.Paths import Path
 from zenmapCore.UmitLogging import log
@@ -253,14 +261,16 @@ class Profile(UmitConfigParser, object):
     def __init__(self, user_profile=None, *args):
         UmitConfigParser.__init__(self, *args)
 
-        if not user_profile:
-            user_profile = Path.scan_profile
+        try:
+            if not user_profile:
+                user_profile = Path.scan_profile
 
-        fconf = open(user_profile, 'r')
-        self.readfp(fconf, user_profile)
-
-        fconf.close()
-        del(fconf)
+            self.read(user_profile)
+        except ConfigParser_Error as e:
+            # No scan profiles found is not a reason to crash.
+            self.add_profile(_("Profiles not found"),
+                    command="nmap",
+                    description=_("The {} file is missing or corrupted").format(user_profile))
 
         self.attributes = {}
 
@@ -319,7 +329,6 @@ class WindowConfig(UmitConfigParser, object):
             self.create_section()
 
     def save_changes(self):
-        config_parser.fp = open(Path.user_config_file, 'w')
         config_parser.save_changes()
 
     def create_section(self):
@@ -340,26 +349,41 @@ class WindowConfig(UmitConfigParser, object):
             value = int(self._get_it("x", self.default_x))
         except ValueError:
             value = self.default_x
+        except TypeError as e:
+            v = self._get_it("x", self.default_x)
+            log.exception("Trouble parsing x value as int: %s",
+                    repr(v), exc_info=e)
+            value = self.default_x
         return value
 
     def set_x(self, x):
-        self._set_it("x", x)
+        self._set_it("x", "%d" % x)
 
     def get_y(self):
         try:
             value = int(self._get_it("y", self.default_y))
         except ValueError:
             value = self.default_y
+        except TypeError as e:
+            v = self._get_it("y", self.default_y)
+            log.exception("Trouble parsing y value as int: %s",
+                    repr(v), exc_info=e)
+            value = self.default_y
         return value
 
     def set_y(self, y):
-        self._set_it("y", y)
+        self._set_it("y", "%d" % y)
 
     def get_width(self):
         try:
             value = int(self._get_it("width", self.default_width))
         except ValueError:
             value = self.default_width
+        except TypeError as e:
+            v = self._get_it("width", self.default_width)
+            log.exception("Trouble parsing width value as int: %s",
+                    repr(v), exc_info=e)
+            value = self.default_width
 
         if not (value >= -1):
             value = self.default_width
@@ -367,13 +391,18 @@ class WindowConfig(UmitConfigParser, object):
         return value
 
     def set_width(self, width):
-        self._set_it("width", width)
+        self._set_it("width", "%d" % width)
 
     def get_height(self):
         try:
             value = int(self._get_it("height", self.default_height))
         except ValueError:
             value = self.default_height
+        except TypeError as e:
+            v = self._get_it("height", self.default_height)
+            log.exception("Trouble parsing y value as int: %s",
+                    repr(v), exc_info=e)
+            value = self.default_height
 
         if not (value >= -1):
             value = self.default_height
@@ -381,7 +410,7 @@ class WindowConfig(UmitConfigParser, object):
         return value
 
     def set_height(self, height):
-        self._set_it("height", height)
+        self._set_it("height", "%d" % height)
 
     x = property(get_x, set_x)
     y = property(get_y, set_y)
@@ -397,6 +426,11 @@ class CommandProfile (Profile, object):
 
     def get_command(self, profile):
         command_string = self._get_it(profile, 'command')
+        # Corrupted config file can include multiple commands. Take the first one.
+        if isinstance(command_string, list):
+            command_string = command_string[0]
+        if not hasattr(command_string, "endswith"):
+            return "nmap"
         # Old versions of Zenmap used to append "%s" to commands and use that
         # to substitute the target. Ignore it if present.
         if command_string.endswith("%s"):
@@ -404,7 +438,10 @@ class CommandProfile (Profile, object):
         return command_string
 
     def get_description(self, profile):
-        return self._get_it(profile, 'description')
+        desc = self._get_it(profile, 'description')
+        if isinstance(desc, list):
+            desc = " ".join(desc)
+        return desc
 
     def set_command(self, profile, command=''):
         self._set_it(profile, 'command', command)
